@@ -5,6 +5,7 @@ LastEditors: Rustle Karl
 LastEditTime: 2022.02.03 9:17
 '''
 import os
+import sys
 
 import click
 
@@ -15,5 +16,15 @@ def writer(conf, content='', read_only=True, official=''):
         with open(conf, 'w', encoding='utf8') as fp:
             fp.write(content)
 
-    click.echo(official)
+    if official:
+        click.echo(official)
+
     click.echo(conf)
+
+
+def is_windows():
+    return sys.platform.startswith('win')
+
+
+def join_user(path):
+    return os.path.join(os.path.expanduser('~'), path)
